@@ -5,6 +5,14 @@ test_description='Attempt to delete branches'
 . ./test-lib.sh
 
 test_expect_success 'Initialize master branch' '
+    test_create_repo origin_repo &&
+    (
+        cd origin_repo &&
+        test_commit_bulk 4
+    ) &&
+    git remote add origin origin_repo &&
+    git fetch origin &&
+    git branch -u origin/master &&
     stg init &&
     test_commit p0 &&
     test_commit p1 &&
@@ -26,7 +34,7 @@ test_expect_success 'Force delete branch with patches' '
 '
 
 test_expect_success 'Make sure the branch ref was deleted' '
-    [ -z "$(git show-ref | grep master | tee /dev/stderr)" ]
+    [ -z "$(git show-ref --heads | grep master | tee /dev/stderr)" ]
 '
 
 test_expect_success 'Make sure the branch config was deleted' '
@@ -36,17 +44,47 @@ test_expect_success 'Make sure the branch config was deleted' '
 '
 
 test_expect_success 'Make sure the branch files were deleted' '
-    [ -z "$(find .git -type f | grep master | tee /dev/stderr)" ]
+    [ -z "$(find .git -type f | grep master | grep -v origin/master | tee /dev/stderr)" ]
 '
 
-test_expect_success 'Attempt to delete current branch' '
-    command_error stg branch --delete $(stg branch) 2>err &&
-    grep -e "cannot delete the current branch" err
+test_expect_success 'Delete current branch' '
+    stg branch -c baz &&
+    stg branch --delete &&
+    stg branch >out &&
+    cat >expected <<-\EOF &&
+	foo
+	EOF
+    test_cmp expected out
+'
+
+test_expect_success 'Attempt delete current branch with patches' '
+    stg branch -c baz2 &&
+    stg new -m p0 &&
+    command_error stg branch --delete 2>err &&
+    grep "delete not permitted: the series still contains patches" err &&
+    stg branch --delete --force &&
+    stg branch >out &&
+    cat >expected <<-\EOF &&
+	foo
+	EOF
+    test_cmp expected out
+'
+
+test_expect_success 'Attempt delete current branch with dirty worktree' '
+    stg branch -c baz2 &&
+    echo content >>p0.t &&
+    command_error stg branch --delete 2>err &&
+    grep "cannot delete the current branch: worktree not clean" err &&
+    git checkout -- p0.t &&
+    stg branch --delete &&
+    stg branch >out &&
+    cat >expected <<-\EOF &&
+	foo
+	EOF
+    test_cmp expected out
 '
 
 test_expect_success 'Invalid num args to delete' '
-    general_error stg branch --delete 2>err &&
-    grep -e "the following required arguments were not provided" err &&
     general_error stg branch --delete foo extra 2>err &&
     grep -e "unexpected argument .extra." err
 '
